@@ -139,8 +139,8 @@ struct _MetaWindow
   /* Whether we're trying to constrain the window to be fully onscreen */
   guint require_fully_onscreen : 1;
 
-  /* Whether we're trying to constrain the window to be on a single xinerama */
-  guint require_on_single_xinerama : 1;
+  /* Whether we're trying to constrain the window to be on a single monitor */
+  guint require_on_single_monitor : 1;
 
   /* Whether we're trying to constrain the window's titlebar to be onscreen */
   guint require_titlebar_visible : 1;
@@ -316,6 +316,9 @@ struct _MetaWindow
    */
   int unmaps_pending;
 
+  /* See docs for meta_window_get_stable_sequence() */
+  guint32 stable_sequence;
+
   /* set to the most recent user-interaction event timestamp that we
      know about for this window */
   guint32 net_wm_user_time;
@@ -456,8 +459,6 @@ void        meta_window_resize_with_gravity (MetaWindow  *window,
 /* Return whether the window should be currently mapped */
 gboolean    meta_window_should_be_showing   (MetaWindow  *window);
 
-gboolean    meta_window_toplevel_is_mapped  (MetaWindow  *window);
-
 /* See warning in window.c about this function */
 gboolean    __window_is_terminal (MetaWindow *window);
 
@@ -546,13 +547,13 @@ GList* meta_window_get_workspaces (MetaWindow *window);
 gboolean meta_window_located_on_workspace (MetaWindow    *window,
                                            MetaWorkspace *workspace);
 
-void meta_window_get_work_area_current_xinerama (MetaWindow    *window,
-                                                 MetaRectangle *area);
-void meta_window_get_work_area_for_xinerama     (MetaWindow    *window,
-                                                 int            which_xinerama,
-                                                 MetaRectangle *area);
-void meta_window_get_work_area_all_xineramas    (MetaWindow    *window,
-                                                 MetaRectangle *area);
+void meta_window_get_work_area_current_monitor (MetaWindow    *window,
+                                                MetaRectangle *area);
+void meta_window_get_work_area_for_monitor     (MetaWindow    *window,
+                                                int            which_monitor,
+                                                MetaRectangle *area);
+void meta_window_get_work_area_all_monitors    (MetaWindow    *window,
+                                                MetaRectangle *area);
 
 
 gboolean meta_window_same_application (MetaWindow *window,
